# Users Overview
### On this page
  * [User Statuses](https://help.sap.com/docs/leanix/ea/users-overview#user-statuses)
  * [Contacts](https://help.sap.com/docs/leanix/ea/users-overview#contacts)
  * [User Details](https://help.sap.com/docs/leanix/ea/users-overview#user-details)


View workspace users and manage their access permissions and roles.
In the Users section of the administration area, you can do the following:
  * View and manage workspace users and contacts
  * View user details and change their roles
  * Export user data by clicking Export


![Users Section in the Administration Area](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27472be17a44101493a897749c13c9e0_LowRes.png)
Users Section in the Administration Area
